@@ -4,7 +4,7 @@ sub new {
 	my $class = shift;
 
 	### contains the table of lex keywords (parser syntax e.g. in a ga.l file)
-	$self = { table_object => undef, };
+	$self = { table_object => undef, lexerscanner => undef, };
 
 	bless $self, $class;
 }
@@ -23,13 +23,14 @@ sub init {
 ### API
 ### read in a file to scan for the lexer
 sub scan {
-	### NOTE : use the aggregatee lexeragg1 for matching keywords	
+	### NOTE : formally use the aggregatee lexeragg1 for matching keywords	
 	my ($self, $lexeragg1, $filename) = @_;
 
 	my $filescanreader = lexerscanfilereader->new($filename);
-	### set the tokens initialization 
-	my $lexerscan->new->init_tokensunitoffile($filescanreader->load_system_file);
-	$lexerscan->compute_scan($self->get_lexer_table);
+	### set the tokens initialization of the system 
+	$self->{lexerscanner} = lexerscan->new->init_tokensunitoffile($filescanreader->load_system_file);
+	### scan in the system file
+	$self->{lexerscanner}->compute_scan($self->get_lexer_table);
 }
 
 ### set the lex keyword table in this class
